# Qurro's dependency files

As you can see in this directory, Qurro's visualization interface relies on a
lot of different libraries to run (see
[here](https://github.com/biocore/qurro#dependencies) for a list).

Hopefully most of these filenames are self-explanatory. For reference, I wanted
to mention that the `dataTables.bootstrap4.*` files are from
[here](https://datatables.net/examples/styling/bootstrap4.html) (see the tab
below the table for "JavaScript"/"CSS" dependencies), since it isn't super
clear from just looking at those what they are.

As you're reading this, you may be scoffing at me for manually
including libraries instead of using a more modern solution like NPM + Webpack.
I'd really like to get to that someday (see relevant issue
[here](https://github.com/biocore/qurro/issues/151)) ... but right now I don't
have a lot of time to dedicate to that. One day! (Also, PRs are always welcome
;)
